;
;------------------------------------------------------------------------------
;
; This script makes plots of biological simulations
;
; chla stock
; NO3 stock
; PO4 stock
;
; (c) Martin Vancoppenolle, UCL-ASTR, june 2007
; reviewed may 2008
; reviewed feb 2010, for biological model
; reviewed aug 2014, helsinki
;
;------------------------------------------------------------------------------
;
miss_val = -9999.
i_auto = 1             ; 1=use exp_id.dat; 2=use manual mode with sensitivity runs
plot_type = 'DEFAULT'  ; 
;
;==============================================================================
; General Options
;==============================================================================
;

IF ( i_auto EQ 1 ) THEN BEGIN ; automatic mode

   nruns = 1
   control_run = 'E001' & indir = '' & outdir = '' & dt = 86400 & c_bio_model = 'BFMSI' & site = 'TOURNAI'
   
   OPENR, 11, 'exp_id.dat'
   READF, 11, control_run & READF, 11, indir & READF, 11, outdir 
   READF, 11, dt & READF, 11, c_bio_model & READF, 11, site 
   CLOSE, 11
   
   PRINT, control_run
   PRINT, indir
   PRINT, outdir
   PRINT, dt
   PRINT, c_bio_model
   PRINT, site

ENDIF

;-------------
; Manual mode
;-------------
IF ( i_auto EQ 0 ) THEN BEGIN

   indir_base = '/Users/ioulianikolskaia/Boulot/CODES/BFMLIM_2013/BFM-LIM-2506_2014/LIM/RUN/'
   outdir = '/Users/ioulianikolskaia/Boulot/SCIENCE/PLOT_SCRIPTS/LIM1D_BIO/IDL/plots/'
   dt   = 3600.        ; time step

   control_run = 'LIM_KR_ML'
   sensiti_run = [ ]
;  sensiti_run =  [ 'LIM_KR_SL', 'LIM_KR_BA' ]
   dummy = SIZE(sensiti_run) 
   nruns = dummy(1) + 1 ; sensitivity runs + 1 control run
   print, 'nruns ', nruns

   indir = STRARR(nruns)
   indir(0) = indir_base+control_run+'/'
   FOR i = 1, nruns-1 DO BEGIN
      indir(i) = indir_base+sensiti_run(i-1)+'/'
   ENDFOR

ENDIF

;
;==============================================================================
; Graphic Options
;==============================================================================
;

;--------------------------------
;--- plot_type dependent options
;--------------------------------

IF ( plot_type EQ 'DEFAULT' ) THEN BEGIN

   colors      = [  0, 200 ,   100   ,   240   ,   240   ,   120   ,   120    ]     
   linestyle   = [  0,0    ,    0    ,    1    ,     2   ,     2   ,     1    ]
   thick       = [  5, 5.  ,    5.0  ,    2.0  ,   2.0   ,   2.0   ,    2.0   ]
   stamp_out   = control_run+'_profiles'
   cs          = 1.8 ; charsize
   colorkey    = 'rd'
   ct          = 0
   !X.MARGIN   = [8,3]
   !Y.MARGIN   = [3,3]
   x_size      = 4.
   y_size      = 6.
   add_obs     = 'YES'

ENDIF

file_name = stamp_out+'.ps'

numplot_x = 5       ; number of horizontal plots
numplot_y = 2       ; number of vertical plots

device = 'PS'       ; 'PS' or 'X'

;--------------------------------
;--- define output plots
;--------------------------------
figuresize_x = numplot_x * x_size ; figure size on x direction
figuresize_y = numplot_y * y_size ; figure size on y direction
set_plot, device
IF ( device EQ 'PS' ) THEN BEGIN
   device, /COLOR, /LANDSCAPE, filename=outdir+file_name, $
           XSIZE=figuresize_x,YSIZE=figuresize_y,FONT_SIZE=9.0
   loadct, ct
ENDIF

IF ( device EQ 'X' ) THEN BEGIN
   xsize = 1200
   ysize = 800
   init_graphics_x, xsize, ysize, colorkey
ENDIF

;
;==============================================================================
; EXTRACT DATA
;==============================================================================
;
;open_fields_v6, indir(0), control_run, c_bio_model, $
;                numt, doy, ts_d, ts_m,                        $
;                h_i, h_s, z_ip, z_ib, s_i, t_i, e_i, PAR, Ra, $
;                dhib, dhisu, dhisi,                           $
;                DAFb, NO3b, PO4b, DSib, chla,                 $
;                DAFt, NO3t, PO4t, DSit,                       $
;                FDAbd, FDAbpos, FDAsi,                        $
;                FNO3, FNO3bpos, FNO3si,                       $
;                syn, lys, rem,                                $
;                lim_lig, lim_no3, lim_po4, lim_dsi, lim_tem, lim_sal
                
 open_fields_v7, indir(0), control_run, c_bio_model, $
                 numt, doy, ts_d, ts_m,                        $
                 h_i, h_s, z_ip, z_ib, s_i, t_i, e_i, PAR, Ra, $
                 dhib, dhisu, dhisi,                           $
                 DAFb, NO3b, PO4b, DSib, chla, eoCb,           $
                 Argb, Argbub, $
                 Oxyb, Oxybub, $
                 DICb, Alkb, CO2b, CO2bub,                     $
                 CO2aq, HCO3m, CO32m, pH, pCO2, Ikab,          $
                 dFeb, aFeb, eFeb,                             $
                 DAFt, NO3t, PO4t, DSit, eoCt, Argt,           $
                 DICt, Alkt, CO2t, Ikat,                       $
                 dFet, aFet, eFet,                             $
                 FDAbd, FDAbpos, FDAsi,                        $
                 FNO3, FNO3bpos, FNO3si,                       $
                 FCO2_atm, FCO2_bub,                           $
                 syn, lys, rem,                                $
                 lim_lig, lim_no3, lim_po4, lim_dsi, lim_tem, lim_sal

zsize = SIZE(DAFb)
nlay = zsize(1)   ; number of layers
nts  = zsize(2)   ; number of time steps

;
;------------------------------------------------------------------------------
; OBS ...
;------------------------------------------------------------------------------
;

; observed normalized profiles from Lannuzel et al. (2007)

N_obs = 7 ; station numbers
N_dpt = 6 ; number of depths

; DOY
doy_obs = [  334,    339,    344,    349,   354,   360,  365 ]

; Ice thickness / snow depth (ULB SITE)
hi_obs = [ 0.90 ,  0.92 ,  0.95 ,  0.87 , 0.94 , 0.94 , 0.83 ]
hs_obs = [ 0.095,  0.130,  0.25 ,  0.15 , 0.110, 0.088, 0.06 ]

; Depths
depth_obs = FLTARR(N_obs, N_dpt)
depth_obs[0,*] = [ 6, 12, 43, 63, 81, 87 ]  / 100. / hi_obs(0)
depth_obs[1,*] = [ 6, 12, 43, 63, 81, 87 ]  / 100. / hi_obs(1)
depth_obs[2,*] = [ 6, 12, 43, 63, 81, 87 ]  / 100. / hi_obs(2)
depth_obs[3,*] = [4.5,12, 43, 63, 77, 83 ]  / 100. / hi_obs(3)
depth_obs[4,*] = [ 7, 13, 43, 63, 80, 86 ]  / 100. / hi_obs(4)
depth_obs[5,*] = [ 6, 12, 43, 63, 78, 87 ]  / 100. / hi_obs(5)
depth_obs[6,*] = [ 6,12.5,43, 62, 77, 83 ]  / 100. / hi_obs(6)

; Chlorophyll
chla_obs = FLTARR(N_obs, N_dpt)
chla_obs[0,*] = [ 0.35, 0.41, 0.18, 0.08, 3.98, 23.57] ; same
chla_obs[1,*] = [ 0.44, 0.44, 0.45, 0.16, 3.44, 26.47] ; same
chla_obs[2,*] = [ 0.97, 2.22, 0.40, 0.25, 2.56, 21.48] ; not the same
chla_obs[3,*] = [ 0.69, 1.23, 0.27, 0.30, 2.19, 24.23] ; same
chla_obs[4,*] = [ 0.78, 1.06, 0.20, 0.65, 4.20, 28.41] ; same as bug fix 1.0
chla_obs[5,*] = [ 0.70, 0.66, 0.69, 0.29, 3.30, 16.33] ; same
chla_obs[6,*] = [ 1.69, 0.97, 0.59, 0.95, 3.62, 24.77] ; same

; Silicates
dsi_obs = FLTARR(N_obs, N_dpt)
dsi_obs[0,*] = [ 6.1, 1.9, 2.4, 1.5, 2.0,11.2 ]
dsi_obs[1,*] = [ 0.3, 0.7, 0.7, 0.7, 2.8, 8.1 ]
dsi_obs[2,*] = [ 2.2, 1.8, 1.5, 1.3, 0.8, 8.9 ]
dsi_obs[3,*] = [ 0.9, 1.9, 1.2, 0.6, 1.8, 9.9 ]
dsi_obs[4,*] = [ 0.5, 0.7, 1.6, 0.4, 0.7, 7.8 ]
dsi_obs[5,*] = [ 0.6, 1.2, 1.7, 1.2, 1.5, 7.6 ]
dsi_obs[6,*] = [ 0.9, 1.5, 1.4, 2.0, 2.6, miss_val ]

; NOX
nox_obs = FLTARR(N_obs, N_dpt)
nox_obs[0,*] = [ 1.2, 0.5, 0.22, 0.3, 0.4, 7.9 ]
nox_obs[1,*] = [ 0.4, 0.5,  0.5, 0.5, 0.8, 7.4 ]
nox_obs[2,*] = [ 1.4, 1.3,  0.4, 0.9, 0.5, 7.3 ]
nox_obs[3,*] = [ 1.4, 1.9,  0.7, 0.3, 1.9, 11.7]
nox_obs[4,*] = [ 0.8, 1.4,  1.7, 0.7, 0.24, 6.9]
nox_obs[5,*] = [ 0.3, 0.7,  0.0, 0.0, 0.0, 3.0 ]
nox_obs[6,*] = [ 0.0, 0.6,  0.3, 0.4, 1.2, miss_val ]

; PO4
po4_obs = FLTARR(N_obs, N_dpt)
po4_obs[0,*] = [ 1.0, 0.3, 0.2, 1.3, 0.3, 3.0 ]
po4_obs[1,*] = [ 0.0, 0.1, 0.15,0.2, 0.2, 2.8 ]
po4_obs[2,*] = [ 0.1, 0.0, 0.0,0.05, 0.1, 3.2 ]
po4_obs[3,*] = [ 0.4, 0.5, 0.4, 0.3, 0.6, 3.22]
po4_obs[4,*] = [ 0.4, 0.6, 0.5, 0.4, 0.4, 2.2 ]
po4_obs[5,*] = [ 0.1, 0.1, 0.0, 0.0, 0.1, 1.5 ]
po4_obs[6,*] = [ 0.0, 0.1, 0.1, 0.0, 0.1, miss_val ]

; physical observations
; T
t_i_obs = FLTARR(N_obs, N_dpt)
t_i_obs[0,*] = [ -3.1, -2.4, -2.3, -2.1, -2, -1.9 ]
t_i_obs[1,*] = [ -1.7, -2.1, -1.9, -1.6, -1.8, -1.8 ]
t_i_obs[2,*] = [ -1.2, -1.4, -1.9, -1.8, -1.8, -1.8 ]
t_i_obs[3,*] = [ -1.5, -1.4, -1.7, -1.7, -1.8, -1.9 ]
t_i_obs[4,*] = [ -0.4, -1.3, -1.4, -1.5, -1.6, -1.6 ]
t_i_obs[5,*] = [ -0.2, -0.7, -1.2, -1.2, -1.2, -1.4 ]
t_i_obs[6,*] = [ -1.1, -1.2, -1.4, -1.4, -1.6, -1.8 ]



; S-physical core
s_i_obs = FLTARR(N_obs, N_dpt)

s_i_obs[0,*] = [ 8.74000   ,  7.78000    , 6.12000    , 4.60000   ,  5.80000  ,   9.43000 ]
s_i_obs[1,*] = [ 5.91100   ,  5.58700    , 5.32000    , 3.39600   ,  5.22900  ,   8.50800 ]
s_i_obs[2,*] = [ 3.62000   ,  4.34000    , 5.53000    , 5.01000   ,  3.99000  ,   5.16000 ]
s_i_obs[3,*] = [ 8.36000   ,  5.21000    , 3.89000    , 3.39600   ,  4.69000  ,   8.30377 ] 
s_i_obs[4,*] = [ 2.58000   ,  5.97000    , 4.47000    , 3.25000   ,  3.35000  ,   4.65000 ]
s_i_obs[5,*] = [ 0.67000   ,  1.99000    , 4.99000    , 3.71000   ,  3.54000  ,   4.62000 ]
s_i_obs[6,*] = [ 4.78000   ,  4.00000    , 3.93000    , 2.82000   ,  3.95000  ,   6.80384 ]

e_i_obs = - 0.054*s_i_obs / t_i_obs

; brine concentrations
iaddr = where ( dsi_obs NE miss_val )
dsi_br_obs = FLTARR(N_obs, N_dpt)
dsi_br_obs(iaddr) = dsi_obs(iaddr) / e_i_obs(iaddr)

iaddr = where ( po4_obs NE miss_val )
po4_br_obs = FLTARR(N_obs, N_dpt)
po4_br_obs(iaddr) = po4_obs(iaddr) / e_i_obs(iaddr)

iaddr = where ( nox_obs NE miss_val )
nox_br_obs = FLTARR(N_obs, N_dpt)
nox_br_obs(iaddr) = nox_obs(iaddr) / e_i_obs(iaddr)

;*** Mean observed Profiles
t_i_obs_mean = MEAN( t_i_obs, dimension = 1 )
t_i_obs_std = STDDEV( t_i_obs, dimension = 1 )

s_i_obs_mean = MEAN( s_i_obs, dimension = 1 )
s_i_obs_std = STDDEV( s_i_obs, dimension = 1 )

e_i_obs_mean = MEAN( e_i_obs, dimension = 1 )
e_i_obs_std = STDDEV( e_i_obs, dimension = 1 )

depth_obs_mean = MEAN( depth_obs, DIMENSION = 1 )

chla_obs_mean  = MEAN( chla_obs , DIMENSION = 1 )
chla_obs_std = STDDEV( chla_obs, dimension = 1 )

dsi_obs_mean = FLTARR(N_dpt) & dsi_obs_std = FLTARR(N_dpt)
nox_obs_mean = FLTARR(N_dpt) & nox_obs_std = FLTARR(N_dpt)
po4_obs_mean = FLTARR(N_dpt) & po4_obs_std = FLTARR(N_dpt)

FOR i = 0, N_dpt - 1 DO BEGIN
   i_addr = WHERE( dsi_obs(*,i) NE miss_val )
   dsi_obs_mean(i) =  MEAN( dsi_obs(i_addr,i) )
   dsi_obs_std(i)  = STDDEV( dsi_obs(i_addr,i) )
   nox_obs_mean(i) =  MEAN( nox_obs(i_addr,i) )
   nox_obs_std(i)  = STDDEV( nox_obs(i_addr,i) )
   po4_obs_mean(i) =  MEAN( po4_obs(i_addr,i) )
   po4_obs_std(i)  = STDDEV( po4_obs(i_addr,i) )
ENDFOR

;*** Corresponding model mean profiles
t_i_mod_mean = FLTARR(nlay)  & t_i_mod_mean(*) = 0.
t_i_mod_std  = FLTARR(nlay)  & t_i_mod_std (*) = 0.
s_i_mod_mean = FLTARR(nlay)  & s_i_mod_mean(*) = 0.
s_i_mod_std  = FLTARR(nlay)  & s_i_mod_std (*) = 0.
e_i_mod_mean = FLTARR(nlay)  & e_i_mod_mean(*) = 0.
e_i_mod_std  = FLTARR(nlay)  & e_i_mod_std (*) = 0.
chla_mod_mean = FLTARR(nlay) & chla_mod_mean(*) = 0.
chla_mod_std  = FLTARR(nlay) & chla_mod_std (*) = 0.
nox_mod_mean = FLTARR(nlay)  & nox_mod_mean(*) = 0.
nox_mod_std  = FLTARR(nlay)  & nox_mod_std (*) = 0.
po4_mod_mean = FLTARR(nlay)  & po4_mod_mean(*) = 0.
po4_mod_std  = FLTARR(nlay)  & po4_mod_std (*) = 0.
dsi_mod_mean = FLTARR(nlay)  & dsi_mod_mean(*) = 0.
dsi_mod_std  = FLTARR(nlay)  & dsi_mod_std (*) = 0.
FOR i = 0, nlay - 1 DO BEGIN

   FOR i_obs = 0, N_obs - 1 DO BEGIN
      i_mod = WHERE(doy EQ doy_obs(i_obs)-1)
      t_i_mod_mean(i)  = t_i_mod_mean(i) + t_i(i,i_mod) / FLOAT(N_obs)
      s_i_mod_mean(i)  = s_i_mod_mean(i) + s_i(i,i_mod) / FLOAT(N_obs)
      e_i_mod_mean(i)  = e_i_mod_mean(i) + e_i(i,i_mod) / FLOAT(N_obs)
      chla_mod_mean(i) = chla_mod_mean(i) + chla(i,i_mod) / FLOAT(N_obs)
      dsi_mod_mean(i)  = dsi_mod_mean(i) + dsib(i,i_mod) / FLOAT(N_obs)
      nox_mod_mean(i)  = nox_mod_mean(i) + no3b(i,i_mod) / FLOAT(N_obs)
      po4_mod_mean(i)  = po4_mod_mean(i) + po4b(i,i_mod) / FLOAT(N_obs)
   ENDFOR

   zsum   = 0
   zsum_s = 0
   zsum_e = 0
   zsum_c = 0
   zsum_d = 0
   zsum_n = 0
   zsum_p = 0
   FOR i_obs = 0, N_obs - 1 DO BEGIN
      i_mod = WHERE(doy EQ doy_obs(i_obs)-1)
      zsum   = zsum + ( t_i(i,i_mod) - t_i_mod_mean(i) ) ^2 / FLOAT(N_obs)
      zsum_s = zsum_s + ( s_i(i,i_mod) - s_i_mod_mean(i) ) ^2 / FLOAT(N_obs)
      zsum_e = zsum_e + ( e_i(i,i_mod) - e_i_mod_mean(i) ) ^2 / FLOAT(N_obs)
      zsum_c = zsum_c + ( chla(i,i_mod) - chla_mod_mean(i) ) ^2 / FLOAT(N_obs)
      zsum_d = zsum_d + ( dsib(i,i_mod) - dsi_mod_mean(i) ) ^2 / FLOAT(N_obs)
      zsum_n = zsum_n + ( no3b(i,i_mod) - nox_mod_mean(i) ) ^2 / FLOAT(N_obs)
      zsum_p = zsum_p + ( po4b(i,i_mod) - po4_mod_mean(i) ) ^2 / FLOAT(N_obs)
   ENDFOR
   t_i_mod_std(i)  = SQRT( zsum   )
   s_i_mod_std(i)  = SQRT( zsum_s )
   e_i_mod_std(i)  = SQRT( zsum_e )
   chla_mod_std(i) = SQRT( zsum_c )
   nox_mod_std(i)  = SQRT( zsum_n )
   po4_mod_std(i)  = SQRT( zsum_p )
   dsi_mod_std(i)  = SQRT( zsum_d )

ENDFOR

;-------


;
;==============================================================================
; DIAGNOSTICS
;==============================================================================
;
phi=findgen(32)*(!PI*2/32.)
phi = [ phi, phi(0) ]
usersym, cos(phi), sin(phi), /fill

;
;==============================================================================
; PLOTS
;==============================================================================
;
;
;==============================================================================
; Time series of profiles 
;==============================================================================
;
;---------
;--- T ---
;---------
!P.MULTI=[0,numplot_x, numplot_y]
FOR i_obs = 0, N_obs - 1 DO BEGIN

   ; prepare plot
   LOADCT, 0
   ztitle = STRCOMPRESS(STRING(doy_obs(i_obs)), /REMOVE_ALL)
   PLOT, [ -3, 0. ], [ -1., 0. ], CHARSIZE = cs, /NODATA, SUBTITLE = 'deg C', XTICKFORMAT='(I3)', XMINOR = 2, YMINOR = 2
   XYOUTS, -1, -0.1, ztitle

   ; add obs
   OPLOT, t_i_obs(i_obs,*), - depth_obs(i_obs,*), PSYM = 1, THICK = 3, SYMSIZE = 0.8

   ; add model
   i_mod = WHERE(doy EQ doy_obs(i_obs)-1)
   zz = FLTARR(nlay)
   FOR i = 0, nlay - 1 DO BEGIN
      zz(i) = z_ip(i,i_mod) / h_i(i_mod)
   ENDFOR
   LOADCT, 3 
   OPLOT, t_i(*,i_mod), -zz, THICK = 3, COLOR = 150

ENDFOR


;---------
;--- S   
;---------
!P.MULTI=[0,numplot_x, numplot_y]
FOR i_obs = 0, N_obs - 1 DO BEGIN

   ; prepare plot
   LOADCT, 0
   ztitle = STRCOMPRESS(STRING(doy_obs(i_obs)), /REMOVE_ALL)
   PLOT, [0., 15. ], [ -1., 0. ], CHARSIZE = cs, /NODATA, SUBTITLE = 'g/kg', XTICKFORMAT='(I3)', XMINOR = 2, YMINOR = 2
   XYOUTS, 7., -0.1, ztitle

   ; add obs
   OPLOT, s_i_obs(i_obs,*), - depth_obs(i_obs,*), PSYM = 1, THICK = 3, SYMSIZE = 0.8

   ; add model
   i_mod = WHERE(doy EQ doy_obs(i_obs)-1)
   zz = FLTARR(nlay)
   FOR i = 0, nlay - 1 DO BEGIN
      zz(i) = z_ip(i,i_mod) / h_i(i_mod)
   ENDFOR
   LOADCT, 3 
   OPLOT, s_i(*,i_mod), -zz, THICK = 3, COLOR = 150

ENDFOR


;---------
;--- e   
;---------
!P.MULTI=[0,numplot_x, numplot_y]
FOR i_obs = 0, N_obs - 1 DO BEGIN

   ; prepare plot
   LOADCT, 0
   ztitle = STRCOMPRESS(STRING(doy_obs(i_obs)), /REMOVE_ALL)
   PLOT, [0., 50. ], [ -1., 0. ], CHARSIZE = cs, /NODATA, SUBTITLE = '%', XTICKFORMAT='(I3)', XMINOR = 2, YMINOR = 2
   XYOUTS, 15., -0.1, ztitle

   ; add obs
   OPLOT, e_i_obs(i_obs,*)*100., - depth_obs(i_obs,*), PSYM = 1, THICK = 3, SYMSIZE = 0.8

   ; add model
   i_mod = WHERE(doy EQ doy_obs(i_obs)-1)
   zz = FLTARR(nlay)
   FOR i = 0, nlay - 1 DO BEGIN
      zz(i) = z_ip(i,i_mod) / h_i(i_mod)
   ENDFOR
   LOADCT, 3 
   OPLOT, e_i(*,i_mod), -zz, THICK = 3, COLOR = 150

ENDFOR


;--------------
;--- chla
;--------------
!P.MULTI=[0,numplot_x, numplot_y]
FOR i_obs = 0, N_obs - 1 DO BEGIN

   ; prepare plot
   LOADCT, 0
   ztitle = STRCOMPRESS(STRING(doy_obs(i_obs)), /REMOVE_ALL)
   PLOT, [ 0.01, 40. ], [ -1., 0. ], CHARSIZE = cs, /NODATA, SUBTITLE = 'mg chla / m3', XTICKFORMAT='(I3)', XMINOR = 2, YMINOR = 2
   XYOUTS, 27., -0.1, ztitle

   ; add obs
   OPLOT, chla_obs(i_obs,*), - depth_obs(i_obs,*), PSYM = 1, THICK = 3, SYMSIZE = 0.8

   ; add model
   i_mod = WHERE(doy EQ doy_obs(i_obs)-1)
   zz = FLTARR(nlay)
   FOR i = 0, nlay - 1 DO BEGIN
      zz(i) = z_ib(i,i_mod) / h_i(i_mod)
   ENDFOR
   LOADCT, 9 
   OPLOT, chla(*,i_mod), -zz, THICK = 3, COLOR = 150

ENDFOR


;------------
;--- nox  
;------------
!P.MULTI=[0,numplot_x, numplot_y]

FOR i_obs = 0, N_obs - 1 DO BEGIN

   ; prepare plot
   LOADCT, 0
   ztitle = STRCOMPRESS(STRING(doy_obs(i_obs)), /REMOVE_ALL)
   PLOT, [ 0.00, 12. ], [ -1., 0. ], CHARSIZE = cs, /NODATA, SUBTITLE = 'mmmol N / m3', XTICKFORMAT='(I3)', XMINOR = 2, YMINOR = 2
   XYOUTS, 2.2, -0.3, ztitle

   ; add obs
   OPLOT, nox_obs(i_obs,*), - depth_obs(i_obs,*), PSYM = 1, THICK = 3, SYMSIZE = 0.8

   ; add model
   i_mod = WHERE(doy+1 EQ doy_obs(i_obs))
   zz = FLTARR(nlay)
   FOR i = 0, nlay - 1 DO BEGIN
      zz(i) = z_ib(i,i_mod) / h_i(i_mod)
   ENDFOR
   LOADCT, 9 
   OPLOT, no3b(*,i_mod), -zz, THICK = 3, COLOR = 150

   PRINT, ' i_mod : ', i_mod
   PRINT, ' NO3b  : ', no3b(*,i_mod)

ENDFOR


;-------------
;--- po4  
;-------------
!P.MULTI=[0,numplot_x, numplot_y]

FOR i_obs = 0, N_obs - 1 DO BEGIN

   ; prepare plot
   LOADCT, 0
   ztitle = STRCOMPRESS(STRING(doy_obs(i_obs)), /REMOVE_ALL)
   PLOT, [ 0.00, 4.0 ], [ -1., 0. ], CHARSIZE = cs, /NODATA, SUBTITLE = 'mmmol P / m3', XTICKFORMAT='(I2)', XMINOR = 2, YMINOR = 2
   XYOUTS, 0.37, -0.3, ztitle

   ; add obs
   OPLOT, po4_obs(i_obs,*), - depth_obs(i_obs,*), PSYM = 1, THICK = 3, SYMSIZE = 0.8

   ; add model
   i_mod = WHERE(doy EQ doy_obs(i_obs)-1)
   zz = FLTARR(nlay)
   FOR i = 0, nlay - 1 DO BEGIN
      zz(i) = z_ib(i,i_mod) / h_i(i_mod)
   ENDFOR
   LOADCT, 9 
   OPLOT, po4b(*,i_mod), -zz, THICK = 3, COLOR = 150

ENDFOR



;--------------
;--- DSi  
;--------------
!P.MULTI=[0,numplot_x, numplot_y]

FOR i_obs = 0, N_obs - 1 DO BEGIN

   ; prepare plot
   LOADCT, 0
   ztitle = STRCOMPRESS(STRING(doy_obs(i_obs)), /REMOVE_ALL)
   PLOT, [ 0.00, 12. ], [ -1., 0. ], CHARSIZE = cs, /NODATA, SUBTITLE = 'mmmol Si / m3', XTICKFORMAT='(F4.1)', XMINOR = 2, YMINOR = 2
   XYOUTS, 0.37, -0.3, ztitle

   ; add obs
   OPLOT, dsi_obs(i_obs,*), - depth_obs(i_obs,*), PSYM = 1, THICK = 3, SYMSIZE = 0.8

   ; add model
   i_mod = WHERE(doy EQ doy_obs(i_obs)-1)
   zz = FLTARR(nlay)
   FOR i = 0, nlay - 1 DO BEGIN
      zz(i) = z_ib(i,i_mod) / h_i(i_mod)
   ENDFOR
   LOADCT, 9 
   OPLOT, dsib(*,i_mod), -zz, THICK = 3, COLOR = 150

ENDFOR

;
;==============================================================================
; Time series of profiles, brine concentrations
;==============================================================================
;

;--- nox_br
!P.MULTI=[0,numplot_x, numplot_y]

FOR i_obs = 0, N_obs - 1 DO BEGIN

   ; prepare plot
   LOADCT, 0
   ztitle = STRCOMPRESS(STRING(doy_obs(i_obs)), /REMOVE_ALL)
   PLOT, [ 0., 30. ], [ -1., 0. ], CHARSIZE = cs, /NODATA, SUBTITLE = 'mmmol N / m3', XTICKFORMAT='(I3)', XMINOR = 2, YMINOR = 2
   XYOUTS, 20.0, -0.15, ztitle

   ; add obs
   OPLOT, nox_br_obs(i_obs,*), - depth_obs(i_obs,*), PSYM = 1, THICK = 3, SYMSIZE = 0.8

   ; add model
   i_mod = WHERE(doy EQ doy_obs(i_obs)-1)
   zz = FLTARR(nlay)
   FOR i = 0, nlay - 1 DO BEGIN
      zz(i) = z_ib(i,i_mod) / h_i(i_mod)
   ENDFOR
   LOADCT, 9 
   OPLOT, no3b(*,i_mod)/e_i(*,i_mod)*100., -zz, THICK = 3, COLOR = 150
   LOADCT, 1

   OPLOT, [ 1.6, 1.6 ], [ -1., 0.], linestyle = 1, color = 150 , thick = 3

ENDFOR

;--- po4_br
!P.MULTI=[0,numplot_x, numplot_y]

FOR i_obs = 0, N_obs - 1 DO BEGIN

   ; prepare plot
   LOADCT, 0
   ztitle = STRCOMPRESS(STRING(doy_obs(i_obs)), /REMOVE_ALL)
   PLOT, [ 0.0, 15. ], [ -1., 0. ], CHARSIZE = cs, /NODATA, $
         SUBTITLE = 'mmmol P / m3', XTICKFORMAT='(I3)', XMINOR = 2, XTICKS = 3 , YMINOR = 2
   XYOUTS, 10., -0.15, ztitle

   ; add obs
   OPLOT, po4_br_obs(i_obs,*), - depth_obs(i_obs,*), PSYM = 1, THICK = 3, SYMSIZE = 0.8

   ; add model
   i_mod = WHERE(doy EQ doy_obs(i_obs)-1)
   zz = FLTARR(nlay)
   FOR i = 0, nlay - 1 DO BEGIN
      zz(i) = z_ib(i,i_mod) / h_i(i_mod)
   ENDFOR
   LOADCT, 9 
   OPLOT, po4b(*,i_mod)/e_i(*,i_mod)*100., -zz, THICK = 3, COLOR = 150
   LOADCT, 1

   OPLOT, [ 0.24, 0.24 ], [ -1., 0.], linestyle = 1, color = 150 , thick = 3

ENDFOR

;--- dsi_br
!P.MULTI=[0,numplot_x, numplot_y]

FOR i_obs = 0, N_obs - 1 DO BEGIN

   ; prepare plot
   LOADCT, 0
   ztitle = STRCOMPRESS(STRING(doy_obs(i_obs)), /REMOVE_ALL)
   PLOT, [ 0., 30. ], [ -1., 0. ], CHARSIZE = cs, /NODATA, SUBTITLE = 'mmmol Si / m3', XTICKFORMAT='(I3)', XMINOR = 2, YMINOR = 2
   XYOUTS, 20.0, -0.15, ztitle

   ; add obs
   OPLOT, dsi_br_obs(i_obs,*), - depth_obs(i_obs,*), PSYM = 1, THICK = 3, SYMSIZE = 0.8

   ; add model
   i_mod = WHERE(doy EQ doy_obs(i_obs)-1)
   zz = FLTARR(nlay)
   FOR i = 0, nlay - 1 DO BEGIN
      zz(i) = z_ib(i,i_mod) / h_i(i_mod)
   ENDFOR
   LOADCT, 9 
   OPLOT, dsib(*,i_mod)/e_i(*,i_mod)*100., -zz, THICK = 3, COLOR = 150
   LOADCT, 1

   OPLOT, [ 3.90, 3.90 ], [ -1., 0.], linestyle = 1, color = 150 , thick = 3

ENDFOR

;
;==============================================================================
; Mean profiles
;==============================================================================
;
!P.MULTI=[0,numplot_x, numplot_y]

;--- T ---

; prepare plot
LOADCT, 0
ztitle = "Mean T"
PLOT, [ -3, 0. ], [ -1., 0. ], CHARSIZE = cs, /NODATA, SUBTITLE = 'deg C', XTICKFORMAT='(I3)', XMINOR = 2, YMINOR = 2, TITLE = ztitle

; add obs
OPLOT, t_i_obs_mean, - depth_obs_mean, PSYM = 8, THICK = 3, SYMSIZE = 0.8
FOR i = 0, N_dpt - 1 DO BEGIN
   OPLOT, [ t_i_obs_mean(i) - t_i_obs_std(i), t_i_obs_mean(i) + t_i_obs_std(i) ], $
          [ -depth_obs_mean(i), -depth_obs_mean(i) ]
ENDFOR
LOADCT, 3
OPLOT, t_i_mod_mean, -zz, THICK = 3, COLOR = 150
LOADCT, 0
OPLOT, t_i_mod_mean+t_i_mod_std, -zz, THICK = 1, COLOR = 150
OPLOT, t_i_mod_mean-t_i_mod_std, -zz, THICK = 1, COLOR = 150

;--- S ---

; prepare plot
LOADCT, 0
ztitle = "Mean S"
   PLOT, [0., 10. ], [ -1., 0. ], CHARSIZE = cs, /NODATA, SUBTITLE = 'g/kg', XTICKFORMAT='(I3)', XMINOR = 2, YMINOR = 2, TITLE = ztitle

; add obs
OPLOT, s_i_obs_mean, - depth_obs_mean, PSYM = 8, THICK = 3, SYMSIZE = 0.8
FOR i = 0, N_dpt - 1 DO BEGIN
   OPLOT, [ s_i_obs_mean(i) - s_i_obs_std(i), s_i_obs_mean(i) + s_i_obs_std(i) ], $
          [ -depth_obs_mean(i), -depth_obs_mean(i) ]
ENDFOR

; add model
LOADCT, 3
OPLOT, s_i_mod_mean, -zz, THICK = 3, COLOR = 150
LOADCT, 0
OPLOT, s_i_mod_mean+s_i_mod_std, -zz, THICK = 1, COLOR = 150
OPLOT, s_i_mod_mean-s_i_mod_std, -zz, THICK = 1, COLOR = 150

;--- e ---

; prepare plot
LOADCT, 0
ztitle = "Mean e"
   PLOT, [0., 50. ], [ -1., 0. ], CHARSIZE = cs, /NODATA, SUBTITLE = '%', XTICKFORMAT='(I3)', XMINOR = 2, YMINOR = 2, TITLE = ztitle

; add obs
OPLOT, e_i_obs_mean*100., - depth_obs_mean, PSYM = 8, THICK = 3, SYMSIZE = 0.8
FOR i = 0, N_dpt - 1 DO BEGIN
   OPLOT, [ e_i_obs_mean(i) - e_i_obs_std(i), e_i_obs_mean(i) + e_i_obs_std(i) ] * 100., $
          [ -depth_obs_mean(i), -depth_obs_mean(i) ]
ENDFOR

; add model
LOADCT, 3
OPLOT, e_i_mod_mean, -zz, THICK = 3, COLOR = 150
LOADCT, 0
OPLOT, e_i_mod_mean+e_i_mod_std, -zz, THICK = 1, COLOR = 150
OPLOT, e_i_mod_mean-e_i_mod_std, -zz, THICK = 1, COLOR = 150

;--- chl-a ---

; prepare plot
LOADCT, 0
ztitle = "Mean chla"
PLOT, [ 0.01, 40. ], [ -1., 0. ], CHARSIZE = cs, /NODATA, SUBTITLE = 'mg chla / m3', XTICKFORMAT='(I3)', XMINOR = 2, YMINOR = 2, TITLE = ztitle
; add obs
OPLOT, chla_obs_mean, - depth_obs_mean, PSYM = 8, THICK = 3, SYMSIZE = 0.8
FOR i = 0, N_dpt - 1 DO BEGIN
   OPLOT, [ chla_obs_mean(i) - chla_obs_std(i), chla_obs_mean(i) + chla_obs_std(i) ], $
          [ -depth_obs_mean(i), -depth_obs_mean(i) ]
ENDFOR
; plot seawater value
LOADCT, 1
OPLOT, [ 0.155 ], [ -1 ], PSYM = 8, THICK = 3, SYMSIZE = 1.6, COLOR = 150

; add model
LOADCT, 9
OPLOT, chla_mod_mean, -zz, THICK = 3, COLOR = 150
LOADCT, 0
OPLOT, chla_mod_mean+chla_mod_std, -zz, THICK = 1, COLOR = 150
OPLOT, chla_mod_mean-chla_mod_std, -zz, THICK = 1, COLOR = 150

;--- NOX ---

; prepare plot
LOADCT, 0
ztitle = "Mean NOX"
PLOT, [ 0.00, 30. ], [ -1.0, 0. ], CHARSIZE = cs, /NODATA, SUBTITLE = 'mmmol N / m3', XTICKFORMAT='(I3)', XMINOR = 2, YMINOR = 2, TITLE = ztitle
; add obs
OPLOT, nox_obs_mean, - depth_obs_mean, PSYM = 8, THICK = 3, SYMSIZE = 0.8
FOR i = 0, N_dpt - 1 DO BEGIN
   OPLOT, [ nox_obs_mean(i) - nox_obs_std(i), nox_obs_mean(i) + nox_obs_std(i) ], $
          [ -depth_obs_mean(i), -depth_obs_mean(i) ]
ENDFOR

; plot seawater value
LOADCT, 1
OPLOT, [ 26.90 ], [ -1 ], PSYM = 8, THICK = 3, SYMSIZE = 1.6, COLOR = 150

; add model
LOADCT, 9
OPLOT, nox_mod_mean, -zz, THICK = 3, COLOR = 150
LOADCT, 0
OPLOT, nox_mod_mean+nox_mod_std, -zz, THICK = 1, COLOR = 150
OPLOT, nox_mod_mean-nox_mod_std, -zz, THICK = 1, COLOR = 150

;--- PO4 ---

; prepare plot
LOADCT, 0
ztitle = "Mean PO4"
PLOT, [ 0.00, 4.0 ], [ -1., 0. ], CHARSIZE = cs, /NODATA, SUBTITLE = 'mmmol P / m3', XTICKFORMAT='(I2)', XMINOR = 2, YMINOR = 2, TITLE = ztitle
; add obs
OPLOT, po4_obs_mean, - depth_obs_mean, PSYM = 8, THICK = 3, SYMSIZE = 0.8
FOR i = 0, N_dpt - 1 DO BEGIN
   OPLOT, [ po4_obs_mean(i) - po4_obs_std(i), po4_obs_mean(i) + po4_obs_std(i) ], $
          [ -depth_obs_mean(i), -depth_obs_mean(i) ]
ENDFOR

; plot seawater value
LOADCT, 1
OPLOT, [ 2.35 ], [ -1 ], PSYM = 8, THICK = 3, SYMSIZE = 1.6, COLOR = 150

; add model
LOADCT, 9
OPLOT, po4_mod_mean, -zz, THICK = 3, COLOR = 150
LOADCT, 0
OPLOT, po4_mod_mean+po4_mod_std, -zz, THICK = 1, COLOR = 150
OPLOT, po4_mod_mean-po4_mod_std, -zz, THICK = 1, COLOR = 150

;--- DSi ---

; prepare plot
LOADCT, 0
ztitle = "Mean DSi"
PLOT, [ 0.00, 60. ], [ -1., 0. ], CHARSIZE = cs, /NODATA, SUBTITLE = 'mmmol N / m3', XTICKFORMAT='(I2)', XMINOR = 2, YMINOR = 2, TITLE = ztitle
; add obs
OPLOT, dsi_obs_mean, - depth_obs_mean, PSYM = 8, THICK = 3, SYMSIZE = 0.8
FOR i = 0, N_dpt - 1 DO BEGIN
   OPLOT, [ dsi_obs_mean(i) - dsi_obs_std(i), dsi_obs_mean(i) + dsi_obs_std(i) ], $
          [ -depth_obs_mean(i), -depth_obs_mean(i) ]
ENDFOR

; plot seawater value
LOADCT, 1
OPLOT, [ 51.25 ], [ -1 ], PSYM = 8, THICK = 3, SYMSIZE = 1.6, COLOR = 150

; add model
LOADCT, 9
OPLOT, dsi_mod_mean, -zz, THICK = 3, COLOR = 150
LOADCT, 0
OPLOT, dsi_mod_mean+dsi_mod_std, -zz, THICK = 1, COLOR = 150
OPLOT, dsi_mod_mean-dsi_mod_std, -zz, THICK = 1, COLOR = 150

;
;==============================================================================
; End of the script
;==============================================================================
;
IF ( device EQ 'PS' ) THEN BEGIN
   DEVICE, /CLOSE
   SET_PLOT, "X"
   !P.MULTI=[0,2,2]
ENDIF

END

